from django.templatetags.static import static
from django.utils.html import format_html

from wagtail.core import hooks


@hooks.register('insert_editor_css')
def editor_css():
    return format_html(
        '<link rel="stylesheet" href="{}">',
        static('css/wagtail_admin_header_ui.css')
    )


@hooks.register('insert_editor_js')
def editor_js():
    return format_html(
        '<script src="{}"></script>',
        static('js/wagtail_admin_header_ui.js')
    )



from django.db import models
from django.utils.translation import gettext as _

from wagtail.admin.edit_handlers import FieldPanel, StreamFieldPanel
from wagtail.core.fields import StreamField
from wagtail.images.edit_handlers import ImageChooserPanel
from wagtail.snippets.models import register_snippet

from menu_header_wagtail.blocks.navbar_block import NavPageLinkWithSubLinkBlock, NavDocumentLinkWithSubLinkBlock, \
    NavExternalLinkWithSubLinkBlock

NAVIGATION_BLOCKS = [
    ('page_link', NavPageLinkWithSubLinkBlock()),
    ('external_link', NavExternalLinkWithSubLinkBlock()),
    ('document_link', NavDocumentLinkWithSubLinkBlock()),
]


@register_snippet
class HeaderPage(models.Model):
    name = models.CharField(
        max_length=255,
        verbose_name=_('Name header'),
        help_text=_('This option allows you to create different menus for different pages')
    )
    logo_type = models.CharField(
        choices=[
            ('text', _('Text')),
            ('image', _('Image')),
        ],
        default='text',
        verbose_name='Logo type',
        max_length=10,
    )
    image_logo = models.ForeignKey(
        'wagtailimages.Image',
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
        related_name='+',
        verbose_name=_('Image logo'),
        help_text='Max height 50px'
    )
    text_logo = models.CharField(
        null=True,
        blank=True,
        verbose_name='Text Logo',
        max_length=100,
    )
    header_fixed = models.BooleanField(verbose_name='Header fixed?', default=True)

    navigation = StreamField(NAVIGATION_BLOCKS, null=True, blank=True)

    panels = [
        FieldPanel('name'),
        FieldPanel('logo_type'),
        FieldPanel('text_logo'),
        ImageChooserPanel('image_logo'),
        FieldPanel('header_fixed'),
        StreamFieldPanel('navigation')
    ]

    def __str__(self):
        return self.name

    class Meta:
        verbose_name = _('Header page')
        verbose_name_plural = _('Headers Page')



from wagtail.core import blocks
from wagtail.documents.blocks import DocumentChooserBlock
from django.utils.translation import gettext as _


class NavBaseLinkBlock(blocks.StructBlock):
    display_text = blocks.CharBlock(
        required=False,
        max_length=255,
        label=_('Text Menu'),
    )


class NavPageLinkBlock(NavBaseLinkBlock):
    """
    Page link.
    """
    page = blocks.PageChooserBlock(
        label=_('Page'),
    )

    class Meta:
        template = 'menu_header_wagtail/menu/page_link_block.html'
        label = _('URL Page')


class NavDocumentLinkBlock(NavBaseLinkBlock):
    """
    Document link.
    """
    document = DocumentChooserBlock(
        label=_('Document'),
    )

    class Meta:
        template = 'menu_header_wagtail/menu/document_link_block.html'
        label = _('URL Document')


class NavExternalLinkBlock(NavBaseLinkBlock):
    """
    External link.
    """
    link = blocks.CharBlock(
        required=False,
        label=_('URL'),
    )

    class Meta:
        template = 'menu_header_wagtail/menu/external_link_block.html'
        label = _('URL External')


class NavSubLinkBlock(blocks.StructBlock):
    sub_links = blocks.StreamBlock(
        [
            ('page_link', NavPageLinkBlock()),
            ('external_link', NavExternalLinkBlock()),
            ('document_link', NavDocumentLinkBlock()),
        ],
        required=False,
        label=_('Sub menú'),
    )


class NavPageLinkWithSubLinkBlock(NavSubLinkBlock, NavPageLinkBlock):
    """
    Page link with option for sub-links or showing child pages.
    """
    open_page_new_window = blocks.BooleanBlock(
        required=False,
        default=False,
        label=_('Open in a new page'),
        help_text=_('Select if you want to open in a new tab when user clicks'),
    )

    class Meta:
        label = _('URL page with submenu')


class NavDocumentLinkWithSubLinkBlock(NavSubLinkBlock, NavDocumentLinkBlock):
    """
    Document link with option for sub-links.
    """

    class Meta:
        label = _('URL Document with submenu')


class NavExternalLinkWithSubLinkBlock(NavSubLinkBlock, NavExternalLinkBlock):
    """
    External link with option for sub-links.
    """

    class Meta:
        label = _('External URL with submenu')




from django import template

register = template.Library()


@register.inclusion_tag('menu_header_wagtail/header_block.html', takes_context=True, )
def render_header_ui(context, page):
    if page:
        context['page'] = page
    return context


@register.simple_tag
def is_menu_item_dropdown(value):
    return \
        len(value.get('sub_links', [])) > 0 or \
        (
                value.get('show_child_links', False) and len(value.get('page', []).get_children().live()) > 0
        )


@register.simple_tag()
def get_parent_page(page):
    return page.get_parent()



# Generated by Django 3.0.5 on 2020-08-24 22:34

from django.db import migrations, models
import django.db.models.deletion
import wagtail.core.blocks
import wagtail.core.fields
import wagtail.documents.blocks


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('wagtailimages', '0022_uploadedimage'),
    ]

    operations = [
        migrations.CreateModel(
            name='HeaderPage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(help_text='This option allows you to create different menus for different pages', max_length=255, verbose_name='Name header')),
                ('logo_type', models.CharField(choices=[('text', 'Texto'), ('image', 'Imagen')], default='text', max_length=10, verbose_name='Logo type')),
                ('text_logo', models.CharField(blank=True, max_length=100, null=True, verbose_name='Text Logo')),
                ('header_fixed', models.BooleanField(default=True, verbose_name='Header fixed?')),
                ('navigation', wagtail.core.fields.StreamField([('page_link', wagtail.core.blocks.StructBlock([('display_text', wagtail.core.blocks.CharBlock(label='Text Menu', max_length=255, required=False)), ('page', wagtail.core.blocks.PageChooserBlock(label='Página')), ('sub_links', wagtail.core.blocks.StreamBlock([('page_link', wagtail.core.blocks.StructBlock([('display_text', wagtail.core.blocks.CharBlock(label='Text Menu', max_length=255, required=False)), ('page', wagtail.core.blocks.PageChooserBlock(label='Página'))])), ('external_link', wagtail.core.blocks.StructBlock([('display_text', wagtail.core.blocks.CharBlock(label='Text Menu', max_length=255, required=False)), ('link', wagtail.core.blocks.CharBlock(label='URL', required=False))])), ('document_link', wagtail.core.blocks.StructBlock([('display_text', wagtail.core.blocks.CharBlock(label='Text Menu', max_length=255, required=False)), ('document', wagtail.documents.blocks.DocumentChooserBlock(label='Documento'))]))], label='Sub menú', required=False)), ('open_page_new_window', wagtail.core.blocks.BooleanBlock(default=False, help_text='Select if you want to open in a new tab when user clicks', label='Open in a new page', required=False))])), ('external_link', wagtail.core.blocks.StructBlock([('display_text', wagtail.core.blocks.CharBlock(label='Text Menu', max_length=255, required=False)), ('link', wagtail.core.blocks.CharBlock(label='URL', required=False)), ('sub_links', wagtail.core.blocks.StreamBlock([('page_link', wagtail.core.blocks.StructBlock([('display_text', wagtail.core.blocks.CharBlock(label='Text Menu', max_length=255, required=False)), ('page', wagtail.core.blocks.PageChooserBlock(label='Página'))])), ('external_link', wagtail.core.blocks.StructBlock([('display_text', wagtail.core.blocks.CharBlock(label='Text Menu', max_length=255, required=False)), ('link', wagtail.core.blocks.CharBlock(label='URL', required=False))])), ('document_link', wagtail.core.blocks.StructBlock([('display_text', wagtail.core.blocks.CharBlock(label='Text Menu', max_length=255, required=False)), ('document', wagtail.documents.blocks.DocumentChooserBlock(label='Documento'))]))], label='Sub menú', required=False))])), ('document_link', wagtail.core.blocks.StructBlock([('display_text', wagtail.core.blocks.CharBlock(label='Text Menu', max_length=255, required=False)), ('document', wagtail.documents.blocks.DocumentChooserBlock(label='Documento')), ('sub_links', wagtail.core.blocks.StreamBlock([('page_link', wagtail.core.blocks.StructBlock([('display_text', wagtail.core.blocks.CharBlock(label='Text Menu', max_length=255, required=False)), ('page', wagtail.core.blocks.PageChooserBlock(label='Página'))])), ('external_link', wagtail.core.blocks.StructBlock([('display_text', wagtail.core.blocks.CharBlock(label='Text Menu', max_length=255, required=False)), ('link', wagtail.core.blocks.CharBlock(label='URL', required=False))])), ('document_link', wagtail.core.blocks.StructBlock([('display_text', wagtail.core.blocks.CharBlock(label='Text Menu', max_length=255, required=False)), ('document', wagtail.documents.blocks.DocumentChooserBlock(label='Documento'))]))], label='Sub menú', required=False))]))], blank=True, null=True)),
                ('image_logo', models.ForeignKey(blank=True, help_text='Max height 50px', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailimages.Image', verbose_name='Image logo')),
            ],
            options={
                'verbose_name': 'Header page',
                'verbose_name_plural': 'Headers Page',
            },
        ),
    ]
